@@ -6,35 +6,26 @@
  *
  * Increment the reference count for an #AccessibleSelection object.
  *
- * Returns: (no return code implemented yet).
- *
  **/
-int
+void
 AccessibleSelection_ref (AccessibleSelection *obj)
 {
-  Accessibility_Selection_ref (*obj, spi_ev ());
-  return 0;
+  cspi_object_ref (obj);
 }
 
-
 /**
  * AccessibleSelection_unref:
  * @obj: a pointer to the #AccessibleSelection implementor on which to operate. 
  *
  * Decrement the reference count for an #Accessible object.
  *
- * Returns: (no return code implemented yet).
- *
  **/
-int
+void
 AccessibleSelection_unref (AccessibleSelection *obj)
 {
-  Accessibility_Selection_unref (*obj, spi_ev ());
-  return 0;
+  cspi_object_unref (obj);
 }
 
-
-
 /**
  * AccessibleSelection_getNSelectedChildren:
  * @obj: a pointer to the #AccessibleSelection implementor on which to operate.
@@ -49,10 +40,18 @@ AccessibleSelection_unref (AccessibleSelection *obj)
 long
 AccessibleSelection_getNSelectedChildren (AccessibleSelection *obj)
 {
-  return (long)
-    Accessibility_Selection__get_nSelectedChildren (*obj, spi_ev ());
-}
+  long retval;
 
+  cspi_return_val_if_fail (obj != NULL, -1);
+
+  retval =
+    Accessibility_Selection__get_nSelectedChildren (CSPI_OBJREF (obj),
+						    cspi_ev ());
+
+  cspi_return_val_if_ev ("getNSelectedChildren", -1);
+
+  return retval;
+}
 
 /**
  * AccessibleSelection_getSelectedChild:
@@ -75,12 +74,15 @@ Accessible *
 AccessibleSelection_getSelectedChild (AccessibleSelection *obj,
                                       long int selectedChildIndex)
 {
-  Accessibility_Accessible child = 
-    Accessibility_Selection_getSelectedChild (*obj,
-					      (CORBA_long) selectedChildIndex, spi_ev ());
-  spi_warn_ev (spi_ev (), "getSelectedChild");
+  Accessibility_Accessible child;
 
-  return (Accessible *) spi_object_add (child);
+  cspi_return_val_if_fail (obj != NULL, NULL);
+  
+  child = Accessibility_Selection_getSelectedChild (
+    CSPI_OBJREF (obj),
+    (CORBA_long) selectedChildIndex, cspi_ev ());
+
+  return (Accessible *) cspi_object_add (child);
 }
 
 /**
@@ -95,17 +97,23 @@ AccessibleSelection_getSelectedChild (AccessibleSelection *obj,
  *         selection.
  *
  * Returns: #TRUE if the child was successfully selected, #FALSE otherwise.
- *
  **/
-boolean
+SPIBoolean
 AccessibleSelection_selectChild (AccessibleSelection *obj,
                                  long int childIndex)
 {
-  return (boolean)
-    Accessibility_Selection_selectChild (*obj,
-					 (CORBA_long) childIndex, spi_ev ());
-}
+  SPIBoolean retval;
 
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval =
+    Accessibility_Selection_selectChild (CSPI_OBJREF (obj),
+					 (CORBA_long) childIndex, cspi_ev ());
+
+  cspi_return_val_if_ev ("selectChild", FALSE);
+
+  return retval;
+}
 
 /**
  * AccessibleSelection_deselectSelectedChild:
@@ -120,18 +128,23 @@ AccessibleSelection_selectChild (AccessibleSelection *obj,
  *          are asymmettric.
  *
  * Returns: #TRUE if the child was successfully deselected, #FALSE otherwise.
- *
  **/
-boolean
+SPIBoolean
 AccessibleSelection_deselectSelectedChild (AccessibleSelection *obj,
                                            long int selectedChildIndex)
 {
-  return Accessibility_Selection_deselectSelectedChild (
-	  *obj, (CORBA_long) selectedChildIndex, spi_ev ());
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_Selection_deselectSelectedChild (
+    CSPI_OBJREF (obj), (CORBA_long) selectedChildIndex, cspi_ev ());
+
+  cspi_return_val_if_ev ("deselectSelectedChild", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleSelection_isChildSelected:
  * @obj: a pointer to the #AccessibleSelection implementor on which to operate.
@@ -143,19 +156,24 @@ AccessibleSelection_deselectSelectedChild (AccessibleSelection *obj,
  *
  * Returns: #TRUE if the specified child is currently selected,
  *          #FALSE otherwise.
- *
  **/
-boolean
+SPIBoolean
 AccessibleSelection_isChildSelected (AccessibleSelection *obj,
                                      long int childIndex)
 {
-  return (boolean)
-    Accessibility_Selection_isChildSelected (*obj,
-					     (CORBA_long) childIndex, spi_ev ());
+  SPIBoolean retval;
+
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_Selection_isChildSelected (
+    CSPI_OBJREF (obj),
+    (CORBA_long) childIndex, cspi_ev ());
+
+  cspi_return_val_if_ev ("isChildSelected", FALSE);
+
+  return (SPIBoolean) retval;
 }
 
-
-
 /**
  * AccessibleSelection_selectAll:
  * @obj: a pointer to the #AccessibleSelection implementor on which to operate.
@@ -166,15 +184,20 @@ AccessibleSelection_isChildSelected (AccessibleSelection *obj,
  * Returns: #TRUE if successful, #FALSE otherwise.
  *
  **/
-boolean
+SPIBoolean
 AccessibleSelection_selectAll (AccessibleSelection *obj)
 {
-  Accessibility_Selection_selectAll (*obj, spi_ev ());
-  return TRUE; /* TODO: change the bonobo method to return boolean */
+  SPIBoolean retval;
+  
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_Selection_selectAll (CSPI_OBJREF (obj), cspi_ev ());
+
+  cspi_return_val_if_ev ("selectAll", FALSE);
+
+  return retval;
 }
 
-
-
 /**
  * AccessibleSelection_clearSelection:
  * @obj: a pointer to the #AccessibleSelection implementor on which to operate.
@@ -182,11 +205,20 @@ AccessibleSelection_selectAll (AccessibleSelection *obj)
  * Clear the current selection, removing all selected children from the
  *       specified #AccessibleSelection implementor's selection list.
  *
+ * Returns: #TRUE if successful, #FALSE otherwise.
+ *
  **/
-void
+SPIBoolean
 AccessibleSelection_clearSelection (AccessibleSelection *obj)
 {
-  Accessibility_Selection_clearSelection (*obj, spi_ev ());
+  SPIBoolean retval;
+  
+  cspi_return_val_if_fail (obj != NULL, FALSE);
+
+  retval = Accessibility_Selection_clearSelection (CSPI_OBJREF (obj), cspi_ev ());
+  cspi_return_val_if_ev ("clearSelection", FALSE);
+
+  return retval;
 }
 
 
